#    Lunar Rover Expedition - A fun adventure game.
#    Copyright (C) 2013 Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Importion of modules
import pygame
pygame.init()

from code.classes.Text import Text


class Level_Clock( Text ):
	"""
	This class is the blueprint for the clock of a level.
	It counts how long it takes the user to complete a level.
	"""

	def __init__( self, mins, secs, second_in_frames, clock_text, center_xy_position  ):
		"""
		Parameters
			mins				int
				How many minutes have passed?
			secs				int
				How many seconds have passed?
			second_in_Frames	int
				How many frames define 1 second?
			clock_text			string
				The unformatted text to display on the window.
			center_xy_position	( int, int ) or [ int, int ]
				WHere to blit self.image to?
		"""

		# I store the passed parameters.  I need them later.
		self._mins = mins
		self._secs = secs
		self._second_in_frames = second_in_frames
		self._clock_text = clock_text
		self._center_xy_position = center_xy_position

		self._frame_counter = 0

		# The formatted clock text.
		self.update_clock_text()

		# Draw the time onto self.image
		super( Level_Clock, self ).__init__( self._formatted_clock_text, self._center_xy_position )


	def update_time( self ):
		"""
		Updates the time.
		"""

		if self._frame_counter >= self._second_in_frames:
			self._frame_counter = 0

			if self._secs == 59:
				self._secs = 0
				self._mins += 1
			else:
				self._secs += 1

			# Update the clock text now, so it can be re-rendered.
			self.update_clock_text()
			self.re_render_clock_text()

		else:
			self._frame_counter += 1


	def update_clock_text( self ):
		"""
		Updates the clock text, so it can be used for blitting it onto self.image.
		"""

		self._formatted_clock_text = self._clock_text.format( self._mins, self._secs )


	def re_render_clock_text( self ):
		"""
		Re-renders the clock text.  Updates the time that is displayed on the window.
		"""

		self.update( self._formatted_clock_text )
