#    Lunar Rover Expedition - A fun adventure game.
#    Copyright (C) 2013 Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Importion of modules
import math
import pygame
pygame.init()

from code.classes.Text import Text


class Lunar_Rover_Energy_Meter( Text ):
	"""
	Thic class implements the energy meter of the lunar rover.
	The energy meter of the lunar rover shows, how much energy (in %) is still available).
	"""

	
	def __init__( self, max_energy, min_energy, current_energy, center_xy_position, energy_meter_text, energy_production, energy_increase_interval ):
		"""
		Parameters
			max_energy					int
				The maximum amount of energy that can be stored in the "solar battery".  Generally 100.
			min_energy					int
				The minimum amount of energy that can be available.  Generally 0.
			current_energy				int
				The amount of energy available at the start and during the game.  This varies during the game and goes up or down as the game continues.
			center_xy_position			( int, int ) or [ int, int ]
				The position of the Energy Meter on the window.
			energy_meter_text			string
				Contains the "yet to be formatted" text of the energy meter that will be displayed on the window.  This is what will be drawn on the surface of "self.image".
			energy_production		int
				The amount of energy that the solar panel collects every time the internal interval has been reached.  This will be added to "self._current_energy" during the game.
			energy_increase_interval	int
				Defines the interval of how long it takes the solar panel to add an amount of energy to "self._current_energy"
		"""
				

		# I store the passed parameters, as I might reuse them later on.
		self._max_energy = max_energy
		self._min_energy = min_energy
		self._current_energy = current_energy
		self._center_xy_position = center_xy_position
		self._energy_meter_text = energy_meter_text
		self._energy_production = energy_production
		self._energy_increase_interval = energy_increase_interval

		self._energy_increase_interval_counter = 0
		
		# I format the text before being displayed.
		self._energy_meter_text_formatted = self._energy_meter_text.format( self._current_energy )

		# Render the text now and position it.
		super( Lunar_Rover_Energy_Meter, self ).__init__( self._energy_meter_text_formatted, self._center_xy_position )


	def energy_increase_by_solar_panel( self ):
		"""
		Increases the energy available in pre-defined intervals.
		"""

		if self._energy_increase_interval_counter >= self._energy_increase_interval:
			self._energy_increase_interval_counter = 0
			self.increase_energy( self._energy_production )

		self._energy_increase_interval_counter += 1

	def decrease_energy( self, amount ):
		"""
		Decreases the energy of the lunar rover.

		Parameters
			amount	int
				The amount to be subtracted of the energy available.
		"""

		self._current_energy -= amount


		if math.floor( self._current_energy ) <= math.floor( self._min_energy ):
			self._current_energy = self._min_energy

		# The energy amount has changed.  I update the text on the window.
		self.update_text()


	def update_text( self ):
		"""
		Updates the text that is being displayed.
		"""

		self._energy_meter_text_formatted = self._energy_meter_text.format( self._current_energy )
		self.update( self._energy_meter_text_formatted )


	def increase_energy( self, amount ):
		"""
		Increases the energy.

		Parameters
			amount 	int
				The amount to be added to the energy available.
		"""

		self._current_energy += amount

		if self._current_energy > self._max_energy:
			self._current_energy = self._max_energy

		# The energy amount has changed.  I update the text on the window.
		self.update_text()
