#    Lunar Rover Expedition - A fun adventure game.
#    Copyright (C) 2013 Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Importion of modules
import math

import pygame
pygame.init()

from code.classes.Animated_Sprite import Animated_Sprite
from code.other.helpers import load_image


class Shot( Animated_Sprite ):
	"""
	The Lunar Rover can shoot projectiles that can destroy enemies or aliens.
	"""

	shot_image = None

	def __init__( self, image_file_names, center_start_pos, speed, window_dimensions, angle, animation_intervals ):
		"""
		Parameters
			image_file_names		( string, string, ... ) or [ string, string, ... ]
				A tuple or list of image filenames that define the images to be used for the animation.
			center_start_pos		( int, int ) or [ int, int ]
				Defines the starting position of the shot.
			speed					int
				Defines the speed of the EMP shot.
			window_dimensions		( int, int, int, int ) or [ int, int, int, int ]
				Coords for a pygame.Rect, that help to decide, when a shot has to be removed from a sprite group.
				A shot is removed from the sprite group if it has left the window, i.e. not visible anymore.
			angle					int
				Defines with which angle the shot is fired.
			animation_intervales	( int, int, ... ) or [ int, int ]
				A tuple or list of integer values that define the speed of the animation.
		"""
		super( Shot, self ).__init__( image_file_names, animation_intervals )

		# I save the passed arguments, as I might need them again later on.
		self._center_start_pos = center_start_pos
		self._speed = speed
		self._window_dimensions = window_dimensions

		# Here I create a window that is used in conjunction with the shots fired, in order to know, when I can remove them from the sprite group to which they belong.  Otherwise, they would eat up on memory if they were still moving arround without being visible.
		self._window_rect = pygame.Rect( self._window_dimensions ) # NOT USED!
		self._angle = angle
		self._velocity_x = 0
		self._velocity_y = 0

		# Make a copy of the original image and rotate it.  A shot can be fired at different angles.
		self.image = pygame.transform.rotate( self.image.copy(), self._angle )
		self.rect = self.image.get_rect( center = self._center_start_pos )

		# Calculate the velocities.
		self.calculate_xy_velocities()


	def update( self ):

		# Update the animation.  If the first animation cycle has ended, kill the sprite, i.e. remove it fromt the sprite group.
		if self.update_animation():
			self.kill()

		# Move the fired shot.
		self.rect.move_ip( self._velocity_x, self._velocity_y )
		
		# Rotate every single image of the animation.
		#self.rotate()

		
	def calculate_xy_velocities( self ):
		"""
		Calculates and sets velocities along the x -and y axis.
		"""

		# I had to add "* -1", because otherwise the shot would fire in the opposite direction.
		# Nasty hack, but works.
		self._velocity_x = self._speed * math.sin( math.radians( self._angle ) ) * -1
		self._velocity_y = self._speed * math.cos( math.radians( self._angle ) ) * -1


	def rotate( self ):
		"""
		Rotates the currently selected image by the class Animated_Sprite
		"""

		# Store the center coords of the sprite.
		self.old_center = self.rect.center
		# Make a copy of the original image and rotate it.
		# Note to self:  HORRIBLE solution.
		self.image = pygame.transform.rotate( self._animation_images[self._shown_image].copy(), self._angle )
		self.rect = self.image.get_rect( center = self.old_center )		


	def enemy_keep_shot_straight( self, moon_rover_xy_velocity ):
		"""
		Only used for enemy shots.  Make sure the shots go straight.
		"""

		self.rect.move_ip( moon_rover_xy_velocity )
