#    Lunar Rover Expedition - A fun adventure game.
#    Copyright (C) 2013 Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Importion of modules
import copy
import pygame
pygame.init()

from code.classes.Enemy import Enemy
from code.classes.Shot import Shot


class Static_Enemy( Enemy ):
	"""
	This is a static enemy.  A static enemy can fire shots, but can't move.
	Usually, these types of enemies are towers.
	"""

	def __init__( self, image_file_names_enemy, animation_intervals_enemy, shot_data, health_points, projectile_damage, name, left_top_position, shooting_interval, detection_distance ):
		super( Static_Enemy, self ).__init__( image_file_names_enemy, animation_intervals_enemy, health_points, projectile_damage, name, left_top_position, detection_distance )

		# Store some of the parameters that have been passed.
		self._shot_data = copy.deepcopy( shot_data )
		
		self._shooting_interval = shooting_interval
		self._shooting_interval_counter = 0
		
		# I save the shots in a sprite group.
		self._fired_shots = pygame.sprite.Group()

		self._lunar_rover_within_range = True


	def update( self, moon_rover_xy_velocity ):
		"""
		Parameters
			moon_rover_xy_velocity
				Defines where the enemy should be moved to when the player moves with his lunar rover.
		"""

		super( Static_Enemy, self ).update( moon_rover_xy_velocity )

		# Is the player within range?
		if not self._sleep:
			if self.is_fire_new_shot():
				# Fire a shot.
				self._shot_data["center_start_pos"] = self.rect.center
				self._fired_shots.add( Shot( **self._shot_data ) )

		# Update any shots that have been fired.
		self._fired_shots.update()

		# Make sure the shots stay in the same position and do not "alter" they angle.
		for s in self._fired_shots:
			s.enemy_keep_shot_straight( moon_rover_xy_velocity )

	def is_fire_new_shot( self ):
		"""
		Returns true if a new shot can be fired.
		"""

		if self._shooting_interval_counter >= self._shooting_interval:
			self._shooting_interval_counter = 0
			return True
		else:
			self._shooting_interval_counter += 1
			return False


	def set_shot_angle( self, angle ):
		"""
		Sets the shooting angle (in degrees).

		Parameters
			angle			int
				The angle to shoot at.
		"""

		self._shot_data["angle"] = angle
