#    Lunar Rover Expedition - A fun adventure game.
#    Copyright (C) 2013 Jannik Haberbosch
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Importion of modules
import pygame
pygame.init()

from code.classes.Text import Text


class Transition( pygame.sprite.Sprite ):
	"""
	A simple transition that can either fade in from the right, or fade out to the left.
	Including some text, that displayed in the center of the screen.
	"""

	def __init__( self, window_dimensions, text, font_size, font_color, bg_color, transition_speed, waiting_time=0, fade_in=True ):
		"""
		waiting_time only applies to transitions that fade in.
		"""

		self._window_dimensions = window_dimensions
		self._text = text
		self._font_size = font_size
		self._font_color = font_color
		self._bg_color = bg_color
		self._transition_speed = transition_speed
		self._waiting_time = waiting_time
		self._waiting_time_counter = 0

		self._fade_in = fade_in


		# Create the sprite.
		self.image = pygame.Surface( self._window_dimensions )
		self.image.fill( self._bg_color )

		# Either fade it in or fade it out.
		if self._fade_in:
			self.rect = self.image.get_rect( topleft = ( self._window_dimensions[0], 0 ) )
		else:
			self.rect = self.image.get_rect( topleft = ( 0, 0 ) )


		# Render the text and blit it in the center of self.image
		self._rendered_text = Text( self._text, ( self._window_dimensions[0] / 2, self._window_dimensions[1] / 2 ), font_size=self._font_size )
		self.image.blit( self._rendered_text.image, self._rendered_text.rect )


	def update( self ):
		return self.move()


	def move( self ):
		"""
		Fade in or fade out.
		"""

		if self._fade_in:
			if self.rect.left >= 0:
				self.rect.move_ip( -self._transition_speed, 0 )
			else:
				if self._waiting_time_counter >= self._waiting_time:
					return False
				else:
					self._waiting_time_counter += 1

		if not self._fade_in:
			if self.rect.right >= 0:
				self.rect.move_ip( -self._transition_speed, 0 )
			else:
				return False
		return True
